import asyncio, time, sys
import time
from spider_rs import Website

async def main():
    print("benching spider-rs(python)...")
    url = len(sys.argv) > 1 and str(sys.argv[1]) or "https://rsseau.fr"
    website = Website(url)
    start = time.time()
    website.crawl()
    end = time.time()
    links = website.get_links()
    print(url, "pages found " + str(len(links)), "elasped duration " + str(end - start) + "s", sep="\n")

asyncio.run(main())


import asyncio
from spider_rs import Website

async def main():
    website = Website("https://www.drake.com")

    class Subscription:
        def __init__(self): 
            print("Subscription Created...") 
        def __call__(self, page): 
            print(page.url + " - status: " + str(page.status_code))
            # if (website.size >= 100):
            #     website.stop()
            
    website.crawl(Subscription())

asyncio.run(main())


import asyncio

from spider_rs import Website

async def main():
    website = Website("https://choosealicense.com", False).with_agent("BotBot").with_headers({ "authorization": "Something "})
    website.crawl()
    print(website.get_links())

asyncio.run(main())


import asyncio
import time
from spider_rs import Website

async def main():
    website = Website("https://choosealicense.com", False)
    a = time.time()
    website.crawl()
    print(website.get_links())
    print("time " + str((time.time() - a)))

asyncio.run(main())


import asyncio
import time

from spider_rs import Website

class Subscription:
    def __init__(self): 
        print("Subscription Created...") 
    def __call__(self, page): 
        print(page.url + " - status: " + str(page.status_code))

async def main():
    website = Website("https://www.drake.com").with_budget({ "*": 200 })
    a = time.time()
    website.crawl(Subscription())
    print("time " + str((time.time() - a)))

asyncio.run(main())


import time, scrapy, sys
from scrapy.linkextractors import LinkExtractor
from scrapy.spiders import CrawlSpider, Rule
from scrapy.crawler import CrawlerProcess
from urllib.parse import urlparse

url = len(sys.argv) > 1 and str(sys.argv[1]) or "https://rsseau.fr"
host = urlparse(url).hostname

class MySpider(CrawlSpider):
    name = host
    allowed_domains = [host]
    start_urls = [url]
    links = []
    rules = (
        Rule(LinkExtractor(), callback='parse_item', follow=True),
    )

    @classmethod
    def update_settings(cls, settings):
        super().update_settings(settings)
        settings.set("LOG_ENABLED", "false", priority="spider")

    def parse_item(self, response):
        self.links.append(response.url)

print("benching scrappy(python)...")
process = CrawlerProcess()
spider = MySpider
start = time.time()
process.crawl(spider)
process.start()
end = time.time()
print(url, "pages found " + str(len(spider.links)), "elasped duration " + str(end - start) + "s", sep="\n")
